@@ -30,8 +30,8 @@
 #include <assert.h>        /* for assert */
 #include <gnutls/gnutls.h> /* for gnutls_session_int, gnutls_session_t */
 #include <stdarg.h>        /* for va_list */
-#include <stdlib.h>        /* for NULL, atoi */
 #include <stdio.h>         /* for FILE, fprintf and related functions */
+#include <stdlib.h>        /* for NULL, atoi */
 #include <string.h>        /* for strcmp, strlen, strncpy */
 #include <sys/socket.h>    /* for AF_UNIX, connect, socket, SOCK_STREAM */
 #include <sys/un.h>        /* for sockaddr_un, sa_family_t */
@@ -72,10 +72,10 @@ struct osp_param
  */
 struct osp_credential
 {
-  gchar *type;            /**< Credential type */
-  gchar *service;         /**< Service the credential is for */
-  gchar *port;            /**< Port the credential is for */
-  GHashTable *auth_data;  /**< Authentication data (username, password, etc.)*/
+  gchar *type;           /**< Credential type */
+  gchar *service;        /**< Service the credential is for */
+  gchar *port;           /**< Port the credential is for */
+  GHashTable *auth_data; /**< Authentication data (username, password, etc.)*/
 };
 
 /**
@@ -83,11 +83,14 @@ struct osp_credential
  */
 struct osp_target
 {
-  GSList *credentials;    /** Credentials to use in the scan */
-  gchar *exclude_hosts;   /** String defining one or many hosts to exclude */
-  gchar *hosts;           /** String defining one or many hosts to scan */
-  gchar *ports;           /** String defining the ports to scan */
-  gchar *finished_hosts;  /** String defining hosts to exclude as finished */
+  GSList *credentials;      /** Credentials to use in the scan */
+  gchar *exclude_hosts;     /** String defining one or many hosts to exclude */
+  gchar *hosts;             /** String defining one or many hosts to scan */
+  gchar *ports;             /** String defining the ports to scan */
+  gchar *finished_hosts;    /** String defining hosts to exclude as finished */
+  int alive_test;           /** Value defining an alive test method */
+  int reverse_lookup_unify; /** Value defining reverse_lookup_unify opt */
+  int reverse_lookup_only;  /** Value defining reverse_lookup_only opt */
 };
 
 /**
@@ -328,38 +331,51 @@ err_get_version:
  *
  * @param[in]   connection    Connection to an OSP server.
  * @param[out]  vts_version   Parsed scanner version.
+ * @param[out]  error         Pointer to error, if any.
  *
  * @return 0 if success, 1 if error.
  */
 int
-osp_get_vts_version (osp_connection_t *connection, char **vts_version)
+osp_get_vts_version (osp_connection_t *connection, char **vts_version,
+                     char **error)
 {
-  entity_t entity, vts, version;
+  entity_t entity, vts;
+  const char *version;
+  const char *status, *status_text;
+  osp_get_vts_opts_t get_vts_opts;
 
   if (!connection)
     return 1;
 
-  if (osp_send_command (connection, &entity, "<get_version/>"))
+  get_vts_opts = osp_get_vts_opts_default;
+  get_vts_opts.version_only = 1;
+  if (osp_get_vts_ext (connection, get_vts_opts, &entity))
     return 1;
 
+  status = entity_attribute (entity, "status");
+
+  if (status != NULL && !strcmp (status, "400"))
+    {
+      status_text = entity_attribute (entity, "status_text");
+      g_debug ("%s: %s - %s.", __func__, status, status_text);
+      if (error)
+        *error = g_strdup (status_text);
+      free_entity (entity);
+      return 1;
+    }
+
   vts = entity_child (entity, "vts");
   if (!vts)
     {
-      g_warning ("%s: element VTS missing.", __FUNCTION__);
+      g_warning ("%s: element VTS missing.", __func__);
       free_entity (entity);
       return 1;
     }
 
-  version = entity_child (vts, "version");
-  if (!version)
-    {
-      g_warning ("%s: element VERSION missing.", __FUNCTION__);
-      free_entity (entity);
-      return 1;
-    }
+  version = entity_attribute (vts, "vts_version");
 
   if (vts_version)
-    *vts_version = g_strdup (entity_text (version));
+    *vts_version = g_strdup (version);
 
   free_entity (entity);
   return 0;
@@ -398,7 +414,8 @@ osp_get_vts (osp_connection_t *connection, entity_t *vts)
  * @return 0 if success, 1 if error.
  */
 int
-osp_get_vts_ext (osp_connection_t *connection, osp_get_vts_opts_t opts, entity_t *vts)
+osp_get_vts_ext (osp_connection_t *connection, osp_get_vts_opts_t opts,
+                 entity_t *vts)
 {
   if (!connection)
     return 1;
@@ -406,9 +423,17 @@ osp_get_vts_ext (osp_connection_t *connection, osp_get_vts_opts_t opts, entity_t
   if (vts == NULL)
     return 1;
 
+  if (opts.version_only == 1)
+    {
+      if (osp_send_command (connection, vts, "<get_vts version_only='1'/>"))
+        return 1;
+      return 0;
+    }
+
   if (opts.filter)
     {
-      if (osp_send_command (connection, vts, "<get_vts filter='%s'/>", opts.filter))
+      if (osp_send_command (connection, vts, "<get_vts filter='%s'/>",
+                            opts.filter))
         return 1;
       return 0;
     }
@@ -569,7 +594,9 @@ osp_get_scan_status_ext (osp_connection_t *connection,
       return status;
     }
 
-  if (!strcmp (entity_attribute (child, "status"), "init"))
+  if (!strcmp (entity_attribute (child, "status"), "queued"))
+    status = OSP_SCAN_STATUS_QUEUED;
+  else if (!strcmp (entity_attribute (child, "status"), "init"))
     status = OSP_SCAN_STATUS_INIT;
   else if (!strcmp (entity_attribute (child, "status"), "running"))
     status = OSP_SCAN_STATUS_RUNNING;
@@ -577,6 +604,8 @@ osp_get_scan_status_ext (osp_connection_t *connection,
     status = OSP_SCAN_STATUS_STOPPED;
   else if (!strcmp (entity_attribute (child, "status"), "finished"))
     status = OSP_SCAN_STATUS_FINISHED;
+  else if (!strcmp (entity_attribute (child, "status"), "interrupted"))
+    status = OSP_SCAN_STATUS_INTERRUPTED;
 
   free_entity (entity);
   return status;
@@ -596,8 +625,7 @@ osp_get_scan_status_ext (osp_connection_t *connection,
  */
 int
 osp_get_scan_pop (osp_connection_t *connection, const char *scan_id,
-                  char **report_xml, int details, int pop_results,
-                  char **error)
+                  char **report_xml, int details, int pop_results, char **error)
 {
   entity_t entity, child;
   int progress;
@@ -615,9 +643,7 @@ osp_get_scan_pop (osp_connection_t *connection, const char *scan_id,
                          "<get_scans scan_id='%s'"
                          " details='%d'"
                          " pop_results='%d'/>",
-                         scan_id,
-                         pop_results ? 1 : 0,
-                         details ? 1 : 0);
+                         scan_id, pop_results ? 1 : 0, details ? 1 : 0);
   if (rc)
     {
       if (error)
@@ -817,8 +843,7 @@ osp_start_scan (osp_connection_t *connection, const char *target,
  *
  */
 static void
-credential_append_as_xml (osp_credential_t *credential,
-                          GString *xml_string)
+credential_append_as_xml (osp_credential_t *credential, GString *xml_string)
 
 {
   GHashTableIter auth_data_iter;
@@ -831,15 +856,11 @@ credential_append_as_xml (osp_credential_t *credential,
                      credential->port ? credential->port : "");
 
   g_hash_table_iter_init (&auth_data_iter, credential->auth_data);
-  while (g_hash_table_iter_next (&auth_data_iter,
-                                 (gpointer*)&auth_data_name,
-                                 (gpointer*)&auth_data_value))
+  while (g_hash_table_iter_next (&auth_data_iter, (gpointer *) &auth_data_name,
+                                 (gpointer *) &auth_data_value))
     {
-      xml_string_append (xml_string,
-                         "<%s>%s</%s>",
-                         auth_data_name,
-                         auth_data_value,
-                         auth_data_name);
+      xml_string_append (xml_string, "<%s>%s</%s>", auth_data_name,
+                         auth_data_value, auth_data_name);
     }
 
   xml_string_append (xml_string, "</credential>");
@@ -866,16 +887,26 @@ target_append_as_xml (osp_target_t *target, GString *xml_string)
                      target->finished_hosts ? target->finished_hosts : "",
                      target->ports ? target->ports : "");
 
+  if (target->alive_test > 0)
+    xml_string_append (xml_string, "<alive_test>%d</alive_test>",
+                       target->alive_test);
+  if (target->reverse_lookup_unify == 1)
+    xml_string_append (xml_string,
+                       "<reverse_lookup_unify>%d</reverse_lookup_unify>",
+                       target->reverse_lookup_unify);
+  if (target->reverse_lookup_only == 1)
+    xml_string_append (xml_string,
+                       "<reverse_lookup_only>%d</reverse_lookup_only>",
+                       target->reverse_lookup_only);
+
   if (target->credentials)
     {
       g_string_append (xml_string, "<credentials>");
-      g_slist_foreach (target->credentials,
-                       (GFunc) credential_append_as_xml,
+      g_slist_foreach (target->credentials, (GFunc) credential_append_as_xml,
                        xml_string);
       g_string_append (xml_string, "</credentials>");
     }
-  xml_string_append (xml_string,
-                     "</target>");
+  xml_string_append (xml_string, "</target>");
 }
 
 /**
@@ -884,12 +915,10 @@ target_append_as_xml (osp_target_t *target, GString *xml_string)
  * @param[in]     vt_group    VT group data.
  * @param[in,out] xml_string  XML string buffer to append to.
  */
-static void vt_group_append_as_xml (osp_vt_group_t *vt_group,
-                                    GString *xml_string)
+static void
+vt_group_append_as_xml (osp_vt_group_t *vt_group, GString *xml_string)
 {
-  xml_string_append (xml_string,
-                     "<vt_group filter=\"%s\"/>",
-                     vt_group->filter);
+  xml_string_append (xml_string, "<vt_group filter=\"%s\"/>", vt_group->filter);
 }
 
 /**
@@ -903,10 +932,8 @@ static void vt_group_append_as_xml (osp_vt_group_t *vt_group,
 static void
 vt_value_append_as_xml (gpointer id, gchar *value, GString *xml_string)
 {
-  xml_string_append (xml_string,
-                     "<vt_value id=\"%s\">%s</vt_value>",
-                     id ? id : "",
-                     value ? value : "");
+  xml_string_append (xml_string, "<vt_value id=\"%s\">%s</vt_value>",
+                     id ? id : "", value ? value : "");
 }
 
 /**
@@ -915,19 +942,15 @@ vt_value_append_as_xml (gpointer id, gchar *value, GString *xml_string)
  * @param[in]     vt_single   Single VT data.
  * @param[in,out] xml_string  XML string buffer to append to.
  */
-static void vt_single_append_as_xml (osp_vt_single_t *vt_single,
-                                    GString *xml_string)
+static void
+vt_single_append_as_xml (osp_vt_single_t *vt_single, GString *xml_string)
 {
-  xml_string_append (xml_string,
-                     "<vt_single id=\"%s\">",
-                     vt_single->vt_id);
-  g_hash_table_foreach (vt_single->vt_values,
-                        (GHFunc) vt_value_append_as_xml,
+  xml_string_append (xml_string, "<vt_single id=\"%s\">", vt_single->vt_id);
+  g_hash_table_foreach (vt_single->vt_values, (GHFunc) vt_value_append_as_xml,
                         xml_string);
   xml_string_append (xml_string, "</vt_single>");
 }
 
-
 /**
  * @brief Start an OSP scan against a target.
  *
@@ -938,8 +961,7 @@ static void vt_single_append_as_xml (osp_vt_single_t *vt_single,
  * @return 0 on success, -1 otherwise.
  */
 int
-osp_start_scan_ext (osp_connection_t *connection,
-                    osp_start_scan_opts_t opts,
+osp_start_scan_ext (osp_connection_t *connection, osp_start_scan_opts_t opts,
                     char **error)
 {
   gchar *scanner_params_xml = NULL;
@@ -965,11 +987,7 @@ osp_start_scan_ext (osp_connection_t *connection,
 
   xml = g_string_sized_new (10240);
   g_string_append (xml, "<start_scan");
-  if (opts.parallel)
-    xml_string_append (xml, " parallel=\"%d\"", opts.parallel);
-  xml_string_append (xml,
-                     " scan_id=\"%s\">",
-                     opts.scan_id ? opts.scan_id : "");
+  xml_string_append (xml, " scan_id=\"%s\">", opts.scan_id ? opts.scan_id : "");
 
   g_string_append (xml, "<targets>");
   g_slist_foreach (opts.targets, (GFunc) target_append_as_xml, xml);
@@ -979,8 +997,7 @@ osp_start_scan_ext (osp_connection_t *connection,
   if (opts.scanner_params)
     {
       scanner_params_xml = NULL;
-      g_hash_table_foreach (opts.scanner_params,
-                            (GHFunc) option_concat_as_xml,
+      g_hash_table_foreach (opts.scanner_params, (GHFunc) option_concat_as_xml,
                             &scanner_params_xml);
       if (scanner_params_xml)
         g_string_append (xml, scanner_params_xml);
@@ -989,7 +1006,7 @@ osp_start_scan_ext (osp_connection_t *connection,
   g_string_append (xml, "</scanner_params>");
 
   g_string_append (xml, "<vt_selection>");
-  g_slist_foreach (opts.vt_groups, (GFunc)vt_group_append_as_xml, xml);
+  g_slist_foreach (opts.vt_groups, (GFunc) vt_group_append_as_xml, xml);
 
   fprintf (file, "%s", xml->str);
 
@@ -1000,8 +1017,8 @@ osp_start_scan_ext (osp_connection_t *connection,
   list_count = 0;
   while (list_item)
     {
-      list_count ++;
-        vt_single_append_as_xml (list_item->data, xml);
+      list_count++;
+      vt_single_append_as_xml (list_item->data, xml);
 
       list_item = list_item->next;
 
@@ -1288,7 +1305,6 @@ osp_param_free (osp_param_t *param)
   g_free (param);
 }
 
-
 /**
  * @brief Allocate and initialize a new OSP credential.
  *
@@ -1308,10 +1324,8 @@ osp_credential_new (const char *type, const char *service, const char *port)
   new_credential->type = type ? g_strdup (type) : NULL;
   new_credential->service = service ? g_strdup (service) : NULL;
   new_credential->port = port ? g_strdup (port) : NULL;
-  new_credential->auth_data = g_hash_table_new_full (g_str_hash,
-                                                     g_str_equal,
-                                                     g_free,
-                                                     g_free);
+  new_credential->auth_data =
+    g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
   return new_credential;
 }
@@ -1343,8 +1357,7 @@ osp_credential_free (osp_credential_t *credential)
  * @return The requested authentication data or NULL if not available.
  */
 const gchar *
-osp_credential_get_auth_data (osp_credential_t *credential,
-                              const char *name)
+osp_credential_get_auth_data (osp_credential_t *credential, const char *name)
 {
   if (credential == NULL || name == NULL)
     return NULL;
@@ -1359,8 +1372,7 @@ osp_credential_get_auth_data (osp_credential_t *credential,
  * @param[in]  value       The authentication data or NULL to unset.
  */
 void
-osp_credential_set_auth_data (osp_credential_t *credential,
-                              const char *name,
+osp_credential_set_auth_data (osp_credential_t *credential, const char *name,
                               const char *value)
 {
   if (credential == NULL || name == NULL)
@@ -1369,16 +1381,14 @@ osp_credential_set_auth_data (osp_credential_t *credential,
   if (g_regex_match_simple ("^[[:alpha:]][[:alnum:]_]*$", name, 0, 0))
     {
       if (value)
-        g_hash_table_replace (credential->auth_data,
-                              g_strdup (name),
+        g_hash_table_replace (credential->auth_data, g_strdup (name),
                               g_strdup (value));
       else
-        g_hash_table_remove (credential->auth_data,
-                             value);
+        g_hash_table_remove (credential->auth_data, value);
     }
   else
     {
-      g_warning ("%s: Invalid auth data name: %s", __FUNCTION__, name);
+      g_warning ("%s: Invalid auth data name: %s", __func__, name);
     }
 }
 
@@ -1388,13 +1398,14 @@ osp_credential_set_auth_data (osp_credential_t *credential,
  * @param[in]  hosts          The hostnames of the target.
  * @param[in]  ports          The ports of the target.
  * @param[in]  exclude_hosts  The excluded hosts of the target.
+ * @param[in]  alive_test     The alive test method of the target.
  *
  * @return The newly allocated osp_target_t.
  */
 osp_target_t *
-osp_target_new (const char *hosts,
-                const char *ports,
-                const char *exclude_hosts)
+osp_target_new (const char *hosts, const char *ports, const char *exclude_hosts,
+                int alive_test, int reverse_lookup_unify,
+                int reverse_lookup_only)
 {
   osp_target_t *new_target;
   new_target = g_malloc0 (sizeof (osp_target_t));
@@ -1403,6 +1414,11 @@ osp_target_new (const char *hosts,
   new_target->hosts = hosts ? g_strdup (hosts) : NULL;
   new_target->ports = ports ? g_strdup (ports) : NULL;
   new_target->finished_hosts = NULL;
+  new_target->alive_test = alive_test ? alive_test : 0;
+  new_target->reverse_lookup_unify =
+    reverse_lookup_unify ? reverse_lookup_unify : 0;
+  new_target->reverse_lookup_only =
+    reverse_lookup_only ? reverse_lookup_only : 0;
 
   return new_target;
 }
@@ -1414,8 +1430,7 @@ osp_target_new (const char *hosts,
  * @param[in]  finished_hosts The hostnames to consider finished.
  */
 void
-osp_target_set_finished_hosts (osp_target_t *target,
-                               const char *finished_hosts)
+osp_target_set_finished_hosts (osp_target_t *target, const char *finished_hosts)
 {
   g_free (target->finished_hosts);
   target->finished_hosts = finished_hosts ? g_strdup (finished_hosts) : NULL;
@@ -1432,8 +1447,7 @@ osp_target_free (osp_target_t *target)
   if (!target)
     return;
 
-  g_slist_free_full (target->credentials,
-                     (GDestroyNotify) osp_credential_free);
+  g_slist_free_full (target->credentials, (GDestroyNotify) osp_credential_free);
   g_free (target->exclude_hosts);
   g_free (target->hosts);
   g_free (target->ports);
@@ -1502,8 +1516,8 @@ osp_vt_single_new (const char *vt_id)
   new_vt_single = g_malloc0 (sizeof (osp_vt_single_t));
 
   new_vt_single->vt_id = vt_id ? g_strdup (vt_id) : NULL;
-  new_vt_single->vt_values = g_hash_table_new_full (g_str_hash, g_str_equal,
-                                                    g_free, g_free);
+  new_vt_single->vt_values =
+    g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
   return new_vt_single;
 }
@@ -1534,11 +1548,9 @@ osp_vt_single_free (osp_vt_single_t *vt_single)
  * @param[in]  value      The value of the preference.
  */
 void
-osp_vt_single_add_value (osp_vt_single_t *vt_single,
-                         const char *name, const char *value)
+osp_vt_single_add_value (osp_vt_single_t *vt_single, const char *name,
+                         const char *value)
 {
-  g_hash_table_replace (vt_single->vt_values,
-                        g_strdup (name),
+  g_hash_table_replace (vt_single->vt_values, g_strdup (name),
                         g_strdup (value));
 }
-
