@@ -177,10 +177,8 @@ gvm_init_gpgme_ctx_from_dir (const gchar *dir)
  *  3 error importing key/certificate, -1 error.
  */
 int
-gvm_gpg_import_many_types_from_string (gpgme_ctx_t ctx,
-                                       const char *key_str,
-                                       ssize_t key_len,
-                                       GArray* key_types)
+gvm_gpg_import_many_types_from_string (gpgme_ctx_t ctx, const char *key_str,
+                                       ssize_t key_len, GArray *key_types)
 {
   gpgme_data_t key_data;
   gpgme_error_t err;
@@ -197,7 +195,7 @@ gvm_gpg_import_many_types_from_string (gpgme_ctx_t ctx,
   if (given_key_type == GPGME_DATA_TYPE_INVALID)
     {
       ret = 1;
-      g_warning ("%s: key_str is invalid", __FUNCTION__);
+      g_warning ("%s: key_str is invalid", __func__);
     }
   else
     {
@@ -205,7 +203,7 @@ gvm_gpg_import_many_types_from_string (gpgme_ctx_t ctx,
       for (index = 0; index < key_types->len; index++)
         {
           if (g_array_index (key_types, gpgme_data_type_t, index)
-                == given_key_type)
+              == given_key_type)
             break;
         }
 
@@ -217,15 +215,13 @@ gvm_gpg_import_many_types_from_string (gpgme_ctx_t ctx,
             {
               if (index)
                 g_string_append (expected_buffer, " or ");
-              g_string_append_printf (expected_buffer,
-                                      "%d",
-                                      g_array_index (key_types,
-                                                    gpgme_data_type_t,
-                                                    index));
+              g_string_append_printf (
+                expected_buffer, "%d",
+                g_array_index (key_types, gpgme_data_type_t, index));
             }
           g_warning ("%s: key_str is not the expected type: "
                      " expected: %s, got %d",
-                     __FUNCTION__, expected_buffer->str, given_key_type);
+                     __func__, expected_buffer->str, given_key_type);
           g_string_free (expected_buffer, TRUE);
         }
     }
@@ -240,12 +236,12 @@ gvm_gpg_import_many_types_from_string (gpgme_ctx_t ctx,
   gpgme_data_release (key_data);
   if (err)
     {
-      g_warning ("%s: Import failed: %s", __FUNCTION__, gpgme_strerror (err));
+      g_warning ("%s: Import failed: %s", __func__, gpgme_strerror (err));
       return 3;
     }
 
   import_result = gpgme_op_import_result (ctx);
-  g_debug ("%s: %d imported, %d not imported", __FUNCTION__,
+  g_debug ("%s: %d imported, %d not imported", __func__,
            import_result->imported, import_result->not_imported);
 
   gpgme_import_status_t status;
@@ -253,10 +249,10 @@ gvm_gpg_import_many_types_from_string (gpgme_ctx_t ctx,
   while (status)
     {
       if (status->result != GPG_ERR_NO_ERROR)
-        g_warning ("%s: '%s' could not be imported: %s", __FUNCTION__,
-                   status->fpr, gpgme_strerror (status->result));
+        g_warning ("%s: '%s' could not be imported: %s", __func__, status->fpr,
+                   gpgme_strerror (status->result));
       else
-        g_debug ("%s: Imported '%s'", __FUNCTION__, status->fpr);
+        g_debug ("%s: Imported '%s'", __func__, status->fpr);
 
       status = status->next;
     };
@@ -283,13 +279,11 @@ gvm_gpg_import_from_string (gpgme_ctx_t ctx, const char *key_str,
                             ssize_t key_len, gpgme_data_type_t key_type)
 {
   int ret;
-  GArray *key_types = g_array_sized_new (FALSE,
-                                         FALSE,
-                                         sizeof (gpgme_data_type_t),
-                                         1);
+  GArray *key_types =
+    g_array_sized_new (FALSE, FALSE, sizeof (gpgme_data_type_t), 1);
   g_array_insert_val (key_types, 0, key_type);
-  ret = gvm_gpg_import_many_types_from_string (ctx, key_str, key_len,
-                                               key_types);
+  ret =
+    gvm_gpg_import_many_types_from_string (ctx, key_str, key_len, key_types);
   g_array_free (key_types, TRUE);
   return ret;
 }
@@ -306,56 +300,75 @@ static gpgme_key_t
 find_email_encryption_key (gpgme_ctx_t ctx, const char *uid_email)
 {
   gchar *bracket_email;
-  gpgme_key_t key;
-  gboolean recipient_found = FALSE;
+  gpgme_key_t key, found_key;
+  gpgme_error_t err;
 
   if (uid_email == NULL)
     return NULL;
 
   bracket_email = g_strdup_printf ("<%s>", uid_email);
 
-  gpgme_op_keylist_start (ctx, NULL, 0);
+  err = gpgme_op_keylist_start (ctx, NULL, 0);
+  if (err)
+    {
+      g_free (bracket_email);
+      g_warning ("gpgme_op_keylist_start failed: %s", gpgme_strerror (err));
+      return NULL;
+    }
+
   gpgme_op_keylist_next (ctx, &key);
-  while (key && recipient_found == FALSE)
+  if (err)
+    {
+      g_free (bracket_email);
+      g_warning ("gpgme_op_keylist_next failed: %s", gpgme_strerror (err));
+      return NULL;
+    }
+
+  found_key = NULL;
+  while (key)
     {
       if (key->can_encrypt)
         {
-          g_debug ("%s: key '%s' OK for encryption", __FUNCTION__,
+          g_debug ("%s: key '%s' OK for encryption", __func__,
                    key->subkeys->fpr);
 
           gpgme_user_id_t uid;
           uid = key->uids;
-          while (uid && recipient_found == FALSE)
+          while (uid && found_key == NULL)
             {
-              g_debug ("%s: UID email: %s", __FUNCTION__, uid->email);
+              g_debug ("%s: UID email: %s", __func__, uid->email);
 
               if (strcmp (uid->email, uid_email) == 0
                   || strstr (uid->email, bracket_email))
                 {
-                  g_message ("%s: Found matching UID for %s", __FUNCTION__,
+                  g_message ("%s: Found matching UID for %s", __func__,
                              uid_email);
-                  recipient_found = TRUE;
+                  found_key = key;
                 }
               uid = uid->next;
             }
         }
       else
         {
-          g_debug ("%s: key '%s' cannot be used for encryption", __FUNCTION__,
+          g_debug ("%s: key '%s' cannot be used for encryption", __func__,
                    key->subkeys->fpr);
         }
 
-      if (recipient_found == FALSE)
-        gpgme_op_keylist_next (ctx, &key);
+      err = gpgme_op_keylist_next (ctx, &key);
+      if (err & GPG_ERR_EOF)
+        break;
+      else if (err)
+        {
+          g_free (bracket_email);
+          g_warning ("gpgme_op_keylist_next failed: %s", gpgme_strerror (err));
+          return NULL;
+        }
     }
 
-  if (recipient_found)
-    return key;
-  else
-    {
-      g_warning ("%s: No suitable key found for %s", __FUNCTION__, uid_email);
-      return NULL;
-    }
+  if (found_key == NULL)
+    g_warning ("%s: No suitable key found for %s", __func__, uid_email);
+
+  return found_key;
 }
 
 /**
@@ -371,7 +384,7 @@ static ssize_t
 gvm_gpgme_fread (void *handle, void *buffer, size_t size)
 {
   int ret;
-  FILE *file = (FILE *)handle;
+  FILE *file = (FILE *) handle;
 
   ret = fread (buffer, 1, size, file);
   if (ferror (file))
@@ -392,7 +405,7 @@ static ssize_t
 gvm_gpgme_fwrite (void *handle, const void *buffer, size_t size)
 {
   int ret;
-  FILE *file = (FILE *)handle;
+  FILE *file = (FILE *) handle;
 
   ret = fwrite (buffer, 1, size, file);
   if (ferror (file))
@@ -400,6 +413,14 @@ gvm_gpgme_fwrite (void *handle, const void *buffer, size_t size)
   return ret;
 }
 
+#define CHECK_ERR(func) \
+  if (err)                                            \
+    {                                                 \
+      printf ("%s: %s failed: %s\n",                  \
+              __func__, func, gpgme_strerror (err));  \
+      return -1;                                      \
+    }
+
 /**
  * @brief  Adds a trust list of all current certificates to a GPG homedir.
  *
@@ -420,31 +441,35 @@ create_all_certificates_trustlist (gpgme_ctx_t ctx, const char *homedir)
   gchar *trustlist_filename;
   GString *trustlist_content;
   GError *g_err;
+  gpgme_error_t err;
 
   g_err = NULL;
   gpgme_set_pinentry_mode (ctx, GPGME_PINENTRY_MODE_CANCEL);
 
-  trustlist_filename = g_build_filename (homedir,
-                                         "trustlist.txt",
-                                         NULL);
+  trustlist_filename = g_build_filename (homedir, "trustlist.txt", NULL);
 
   trustlist_content = g_string_new ("");
 
-  gpgme_op_keylist_start (ctx, NULL, 0);
+  err = gpgme_op_keylist_start (ctx, NULL, 0);
+  CHECK_ERR ("gpgme_op_keylist_start")
   gpgme_op_keylist_next (ctx, &key);
+  CHECK_ERR ("gpgme_op_keylist_next")
   while (key)
     {
       g_string_append_printf (trustlist_content, "%s S\n", key->fpr);
-      gpgme_op_keylist_next (ctx, &key);
+      err = gpgme_op_keylist_next (ctx, &key);
+      if (err & GPG_ERR_EOF)
+        break;
+      else
+        CHECK_ERR ("gpgme_op_keylist_next")
     }
 
-  if (g_file_set_contents (trustlist_filename,
-                           trustlist_content->str,
-                           trustlist_content->len,
-                           &g_err) == FALSE)
+  if (g_file_set_contents (trustlist_filename, trustlist_content->str,
+                           trustlist_content->len, &g_err)
+      == FALSE)
     {
-      g_warning ("%s: Could not write trust list: %s",
-                 __func__, g_err->message);
+      g_warning ("%s: Could not write trust list: %s", __func__,
+                 g_err->message);
       g_free (trustlist_filename);
       g_string_free (trustlist_content, TRUE);
       return -1;
@@ -456,6 +481,22 @@ create_all_certificates_trustlist (gpgme_ctx_t ctx, const char *homedir)
   return 0;
 }
 
+#undef CHECK_ERR
+#define CHECK_ERR(func) \
+  if (err)                                            \
+    {                                                 \
+      printf ("%s: %s failed: %s\n",                  \
+              __func__, func, gpgme_strerror (err));  \
+      if (plain_data)                                 \
+        gpgme_data_release (plain_data);              \
+      if (encrypted_data)                             \
+        gpgme_data_release (encrypted_data);          \
+      if (ctx)                                        \
+        gpgme_release (ctx);                          \
+      gvm_file_remove_recurse (gpg_temp_dir);         \
+      return -1;                                      \
+    }
+
 /**
  * @brief Encrypt a stream for a PGP public key, writing to another stream.
  *
@@ -475,7 +516,7 @@ static int
 encrypt_stream_internal (FILE *plain_file, FILE *encrypted_file,
                          const char *key_str, ssize_t key_len,
                          const char *uid_email, gpgme_protocol_t protocol,
-                         GArray* key_types)
+                         GArray *key_types)
 {
   char gpg_temp_dir[] = "/tmp/gvmd-gpg-XXXXXX";
   gpgme_ctx_t ctx;
@@ -487,10 +528,20 @@ encrypt_stream_internal (FILE *plain_file, FILE *encrypted_file,
   const char *key_type_str;
   struct gpgme_data_cbs callbacks;
 
+  ctx = NULL;
+  plain_data = NULL;
+  encrypted_data = NULL;
+
   if (uid_email == NULL || strcmp (uid_email, "") == 0)
     {
       g_warning ("%s: No email address for user identification given",
-                 __FUNCTION__);
+                 __func__);
+      return -1;
+    }
+
+  if (gpgme_check_version (NULL) == NULL)
+    {
+      g_warning ("%s: gpgme_check_version failed", __func__);
       return -1;
     }
 
@@ -502,25 +553,35 @@ encrypt_stream_internal (FILE *plain_file, FILE *encrypted_file,
   // Create temporary GPG home directory, set up context and encryption flags
   if (mkdtemp (gpg_temp_dir) == NULL)
     {
-      g_warning ("%s: mkdtemp failed\n", __FUNCTION__);
+      g_warning ("%s: mkdtemp failed\n", __func__);
       return -1;
     }
 
-  gpgme_new (&ctx);
+  err = gpgme_new (&ctx);
+  CHECK_ERR ("gpgme_new")
 
   if (protocol == GPGME_PROTOCOL_CMS)
     gpgme_set_armor (ctx, 0);
   else
     gpgme_set_armor (ctx, 1);
 
-  gpgme_ctx_set_engine_info (ctx, protocol, NULL, gpg_temp_dir);
-  gpgme_set_protocol (ctx, protocol);
+  err = gpgme_ctx_set_engine_info (ctx, protocol, NULL, gpg_temp_dir);
+  CHECK_ERR ("gpgme_ctx_set_engine_info")
+
+  err = gpgme_set_protocol (ctx, protocol);
+  CHECK_ERR ("gpgme_set_protocol")
+
+  err = gpgme_set_keylist_mode (ctx, GPGME_KEYLIST_MODE_LOCAL);
+  CHECK_ERR ("gpgme_set_keylist_mode")
+
+  gpgme_set_offline (ctx, 1);
+
   encrypt_flags = GPGME_ENCRYPT_ALWAYS_TRUST | GPGME_ENCRYPT_NO_COMPRESS;
 
   // Import public key into context
   if (gvm_gpg_import_many_types_from_string (ctx, key_str, key_len, key_types))
     {
-      g_warning ("%s: Import of %s failed", __FUNCTION__, key_type_str);
+      g_warning ("%s: Import of %s failed", __func__, key_type_str);
       gpgme_release (ctx);
       gvm_file_remove_recurse (gpg_temp_dir);
       return -1;
@@ -530,7 +591,7 @@ encrypt_stream_internal (FILE *plain_file, FILE *encrypted_file,
   key = find_email_encryption_key (ctx, uid_email);
   if (key == NULL)
     {
-      g_warning ("%s: Could not find %s for encryption", __FUNCTION__,
+      g_warning ("%s: Could not find %s for encryption", __func__,
                  key_type_str);
       gpgme_release (ctx);
       gvm_file_remove_recurse (gpg_temp_dir);
@@ -539,16 +600,18 @@ encrypt_stream_internal (FILE *plain_file, FILE *encrypted_file,
   keys[0] = key;
 
   // Set up data objects for input and output streams
-  gpgme_data_new_from_stream (&plain_data, plain_file);
+  err = gpgme_data_new_from_stream (&plain_data, plain_file);
+  CHECK_ERR ("gpgme_data_new_from_stream for plain text")
 
   /* Create a GPGME data buffer with custom read and write functions.
    *
-   * This is neccessary as gpgme_data_new_from_stream may cause problems
+   * This is necessary as gpgme_data_new_from_stream may cause problems
    * when trying to write to the stream after some operations. */
   memset (&callbacks, 0, sizeof (callbacks));
   callbacks.read = gvm_gpgme_fread;
   callbacks.write = gvm_gpgme_fwrite;
-  gpgme_data_new_from_cbs (&encrypted_data, &callbacks, encrypted_file);
+  err = gpgme_data_new_from_cbs (&encrypted_data, &callbacks, encrypted_file);
+  CHECK_ERR ("gpgme_data_new_from_stream for encrypted text")
 
   if (protocol == GPGME_PROTOCOL_CMS)
     {
@@ -566,17 +629,7 @@ encrypt_stream_internal (FILE *plain_file, FILE *encrypted_file,
 
   // Encrypt data
   err = gpgme_op_encrypt (ctx, keys, encrypt_flags, plain_data, encrypted_data);
-
-  if (err)
-    {
-      g_warning ("%s: Encryption failed: %s", __FUNCTION__,
-                 gpgme_strerror (err));
-      gpgme_data_release (plain_data);
-      gpgme_data_release (encrypted_data);
-      gpgme_release (ctx);
-      gvm_file_remove_recurse (gpg_temp_dir);
-      return -1;
-    }
+  CHECK_ERR ("gpgme_op_encrypt")
 
   gpgme_data_release (plain_data);
   gpgme_data_release (encrypted_data);
@@ -610,9 +663,9 @@ gvm_pgp_pubkey_encrypt_stream (FILE *plain_file, FILE *encrypted_file,
   GArray *key_types = g_array_new (FALSE, FALSE, sizeof (gpgme_data_type_t));
 
   g_array_append_vals (key_types, types_ptr, 1);
-  ret = encrypt_stream_internal (
-    plain_file, encrypted_file, public_key_str, public_key_len, uid_email,
-    GPGME_PROTOCOL_OpenPGP, key_types);
+  ret = encrypt_stream_internal (plain_file, encrypted_file, public_key_str,
+                                 public_key_len, uid_email,
+                                 GPGME_PROTOCOL_OpenPGP, key_types);
   g_array_free (key_types, TRUE);
 
   return ret;
@@ -642,9 +695,9 @@ gvm_smime_encrypt_stream (FILE *plain_file, FILE *encrypted_file,
   GArray *key_types = g_array_new (FALSE, FALSE, sizeof (gpgme_data_type_t));
 
   g_array_append_vals (key_types, types_ptr, 2);
-  ret = encrypt_stream_internal (
-    plain_file, encrypted_file, certificate_str, certificate_len, uid_email,
-    GPGME_PROTOCOL_CMS, key_types);
+  ret = encrypt_stream_internal (plain_file, encrypted_file, certificate_str,
+                                 certificate_len, uid_email, GPGME_PROTOCOL_CMS,
+                                 key_types);
   g_array_free (key_types, TRUE);
 
   return ret;
